#!/usr/bin/env python
# -*- coding: utf-8 -*-

from weichigong import zconfig

zc = None


def setup_module(module):
    pass


def setup_function(function):
    global zc
    zc = zconfig('localhost', 'testapp', 'dev')
    pass


def test_set_value():
    global zc
    zc.set('a/b/c', 'abc')
    assert zc.get('a/b/c') == 'abc'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from kazoo.client import KazooClient

__name__ = "weichigong"
__version__ = '1.0.3'
__author__ = 'dashixiong'
__author_email__ = 'dashixiong.lee@gmail.com'


class zconfig:

    def __init__(self, zkHosts, app, env):
        self.app = app
        self.env = env
        self.client = KazooClient(hosts=zkHosts)
        self.client.start()

    def getPath(self, path):
        return os.path.join('/', self.app, self.env, path)

    def set(self, path, value):
        fullPath = self.getPath(path)
        self.client.ensure_path(fullPath)
        self.client.set(fullPath, value)

    def get(self, path):
        fullPath = self.getPath(path)
        return self.client.get(fullPath)[0].decode('utf-8')



import setuptools
import weichigong

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name=weichigong.__name__,
    version=weichigong.__version__,
    author=weichigong.__author__,
    author_email=weichigong.__author_email__,
    description="a centralized configuration library based on zookeeper",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/perfeelab/weichigong",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
